# `relationalai.Producer.__rmul__()`

```python
relationalai.Producer.__rmul__(other: Any) -> Expression
```

Returns an [`Expression`](../Expression.md) that produces the product of [`Producer`](./README.md) values and `other`.
`.__rmul__()` is implemented so that you may use a non-`Producer` object as the left operand.

#### See Also

[`Producer.__mul__()`](./mul__.md)
